// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('virgin', [
    'ionic',
    'virgin.controllers',
    'virgin.services.localDataService',
    'virgin.services.utils'
])

.run(function ($ionicPlatform, localDataService, utils) {
    $ionicPlatform.ready(function () {        
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
        }
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.styleDefault();
        }

        utils.Init();

        localDataService.initialize();

        // write log to console
        ImgCache.init(function(){
            console.log('imgcache started');
        }, function(error){
            console.log(error);
        });
        // write log to console
        ImgCache.options.debug = true;

        // increase allocated space on Chrome to 50MB, default was 10MB
        ImgCache.options.chromeQuota = 50 * 1024 * 1024;
    });

})

.config(function ($stateProvider, $urlRouterProvider) {

    // Ionic uses AngularUI Router which uses the concept of states
    // Learn more here: https://github.com/angular-ui/ui-router
    // Set up the various states which the app can be in.
    // Each state's controller can be found in controllers.js
    $stateProvider

    // setup an abstract state for the tabs directive

    .state('splash', {
        url: '/splash',
        abstract: false,
        templateUrl: 'templates/splash.html',
        controller: 'splashCtrl'
    })

    .state('intro', {
        url: '/intro',
        abstract: false,
        templateUrl: 'templates/intro.html',
        controller: 'introCtrl'
    })

    .state('tutorials', {
        url: '/tutorials',
        abstract: false,
        templateUrl: 'templates/tutorials.html',
        controller: 'tutorialsCtrl'
    })

    .state('app', {
        url: '/app',
        abstract: true,
        templateUrl: 'templates/-viewstart.html',
    })

    .state('app.signup', {
        url: '/signup',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/signup.html',
                controller: 'SignUpCtrl'
            }
        }
    })


    .state('app.challenges update', {
        url: '/challenges/:update',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/challenges.html',
                controller: 'challengesCtrl'
            }
        }
    })

    .state('app.challenges', {
        url: '/challenges',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/challenges.html',
                controller: 'challengesCtrl'
            }
        }
    })

    .state('app.frequency update', {
        url: '/frequency/:updateBool',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/frequency.html',
                controller: 'frequencyCtrl'
            }
        }
    })

    .state('app.frequency', {
        url: '/frequency',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/frequency.html',
                controller: 'frequencyCtrl'
            }
        }
    })

    .state('app.challengeShare', {
        url: '/challengeShare',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/challengeShare.html',
                controller: 'challengeShareCtrl'
            }
        }
    })

    .state('app.frequencyComplete', {
        url: '/frequencyComplete',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/frequencyComplete.html',
                controller: 'frequencyCompleteCtrl'
            }
        }
    })

    .state('app.gallery', {
        url: '/gallery',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/gallery.html',
                controller: 'galleryCtrl'
            }
        }
        })
        //VIEW DETAIL FROM GALLERY
    .state('app.motivationDetail', {
        url: '/motivationDetail/:challengeID/:motivationID',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/motivationDetail.html',
                controller: 'motivationDetailCtrl'
            }
        }
    })

        //EDIT from gallery
        .state('app.motivationEditFromGallery', {
            url: '/motivationEdit/:challengeID/:motivationID',
            abstract: false,
            views: {
                'page-content': {
                    templateUrl: 'templates/motivationEdit.html',
                    controller: 'motivationEditCtrl'
                }
            }
        })

        //EDIT from intro
        .state('app.motivationEdit', {
            url: '/motivationEdit',
            abstract: false,
            views: {
                'page-content': {
                    templateUrl: 'templates/motivationEdit.html',
                    controller: 'motivationEditCtrl'
                }
            }
        })

     .state('app.imageSelect with parameters', {
         url: '/imageSelect/:challengeID/:motivationID',
         abstract: false,
         views: {
             'page-content': {
                 templateUrl: 'templates/imageSelect.html',
                 controller: 'imageSelectCtrl'
             }
         }
     })

     .state('app.imageSelect', {
         url: '/imageSelect',
         abstract: false,
         views: {
             'page-content': {
                 templateUrl: 'templates/imageSelect.html',
                 controller: 'imageSelectCtrl'
             }
         }
     })

    .state('app.termsPage', {
        url: '/termsPage',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/terms-conditions.html',
                controller: 'termsPageCtrl'
            }
        }
    })

    .state('terms', {
        url: '/terms',
        templateUrl: 'templates/terms-conditions.html'
    })

    .state('app.shareVideo', {
        url: '/shareVideo',
        abstract: false,
        views: {
            'page-content': {
                templateUrl: 'templates/shareVideo.html',
                controller: 'shareVideoCtrl'
            }
        }
    })

    $urlRouterProvider.otherwise('/splash');

});

