﻿'use strict';

angular.module('virgin.services.localDataService', [])
    .factory('localDataService', function () {
        var defaults = {
            databaseName: 'dbVirginActive',
            databaseVersion: '1.0.1',
            databaseSize: 5242880,
            tableNames: {
                profile: 'profile',
                frequency: 'frequency',
                video: 'video'
            }
        };
        var database = new localStorageDB(defaults.databaseName, localStorage);

        //initialize database on load
        var initializeDatabase = function () {
            //if (database.isNew()) {
            if (!database.tableExists(defaults.tableNames.profile)) {
                database.createTable(defaults.tableNames.profile, ['id', 'name', 'email', 'cell', 'membershipnr', 'interested','challengeid']);                
            }

            if (!database.tableExists(defaults.tableNames.frequency)) {
                database.createTable(defaults.tableNames.frequency, ['frequencyId', 'frequencyTimeId']);
            }

            if (!database.tableExists(defaults.tableNames.video)) {
                database.createTable(defaults.tableNames.video, ['id', 'videoUrl']);
            }

            database.commit();
            //}
        };
        //remove everything
        var dropAllTables = function () {
            if (!database.isNew()) {
                database.dropTable(defaults.tableNames.profile, ['id', 'json']);
                database.dropTable(defaults.tableNames.frequency, ['id', 'json']);
                database.dropTable(defaults.tableNames.video, ['id', 'json']);

                database.commit();
            }
        };

        initializeDatabase();

        return {
            initialize: function () {
                initializeDatabase();
            },
            needsUpdating: function(tableName) {
                if (!database.tableExists(tableName)) {
                    initializeDatabase();
                    return true;
                }
                var item = database.query(defaults.tableNames.config, { tableName: tableName });
                if (item == null || item.length == 0)
                    return true;
                
                var timeoutUpdateDate = new Date().getTime() - contentAgeTimeout;
                if (item.updateDate < timeoutUpdateDate) {
                    return true;
                } else {
                    return false;
                }
            },
            tableNames: defaults.tableNames,
            checkLastUpdate: function (tableName) {
                defaults.config.database.get(tableName, function (data) {
                    return data.lastSync;
                });
            },
            getAll: function (tableName) {
                return database.query(tableName);
            },
            truncateTable: function(tableName) {
                database.truncate(tableName);
                database.commit();
            },
            getByQuery: function (tableName, query) {
                return database.query(tableName, query);
            },
            deleteItem: function (tableName, id) {
                database.deleteRows(tableName, { ID: id });
                database.commit();
            },
            updatePin: function(pin, validUntil) {
                database.insertOrUpdate(defaults.tableNames.config, { tableName: 'pin' }, { tableName: 'pin', updateDate: validUntil, pin: pin });
                database.commit();
            },
            updateItem: function (tableName, id, data) {
                database.insertOrUpdate(tableName, { ID: id }, data);
                database.commit();
            },
            updateCache: function (tableName, dataSet) {
                for (var i = 0; i < dataSet.length; i++) {
                    database.insertOrUpdate(tableName, { ID: dataSet[i].id }, dataSet[i]);
                    database.commit();
                }
                //database.insertOrUpdate(defaults.tableNames.config, { tableName: tableName }, { tableName: tableName, updateDate: new Date().getTime() });
                database.commit();
            },
            updateUserCache: function (tableName, dataSet) {
                database.insertOrUpdate(tableName, { ID: 1 }, dataSet);
                database.commit();
            },
            insertNameValueEntry: function (name, value) {
                var item = database.query(defaults.tableNames.nameValueCollection, { name: name });
                if (item.length == 0) {
                    database.insertOrUpdate(defaults.tableNames.nameValueCollection, { ID: item.ID }, { name: name, value: value });
                } else {
                    database.insertOrUpdate(defaults.tableNames.nameValueCollection, { name: name, value: value });
                }
                database.commit();
            },
            getNameValueEntry: function (name) {
                return database.query(defaults.tableNames.nameValueCollection, { name: name });
            },
            __hereBeTheDragons: {
                dropDatabase: {
                    areYouSure: function (really) {
                        if (really) {
                            dropAllTables();
                        }
                    }
                }
            }
        };
    });